@@ -1,11 +1,15 @@
 import json
 import re
+from functools import wraps
 from pathlib import Path
+from typing import Any, Callable, Type
 
 from .format_names import Format
 
 
 def guess_format(path: Path) -> Format:
+    """Try to guess the format of the given file, raise an exception if the
+    format is unknown"""
     if path.is_dir():
         raise ValueError("Can't guess chart format for a folder")
 
@@ -106,17 +110,29 @@ def recognize_jubeat_analyser_format(path: Path) -> Format:
         raise ValueError("Unrecognized file format")
 
 
+def false_if_raises(
+    *exceptions: Type[Exception],
+) -> Callable[[Callable[..., bool]], Callable[..., bool]]:
+    def decorator(f: Callable[..., bool]) -> Callable[..., bool]:
+        @wraps(f)
+        def wrapper(*a: Any, **kw: Any) -> bool:
+            try:
+                return f(*a, **kw)
+            except Exception as e:
+                if exceptions and not isinstance(e, exceptions):
+                    raise
+                else:
+                    return False
+
+        return wrapper
+
+    return decorator
+
+
+@false_if_raises(UnicodeDecodeError, StopIteration)
 def looks_like_eve(path: Path) -> bool:
     with path.open(encoding="ascii") as f:
-        try:
-            line = f.readline()
-        except UnicodeDecodeError:
-            return False
-
-        if line.strip():
-            return looks_like_eve_line(next(f))
-
-    return False
+        return looks_like_eve_line(f.readline())
 
 
 EVE_COMMANDS = {
@@ -152,5 +168,6 @@ def looks_like_eve_line(line: str) -> bool:
 
 
 def looks_like_jbsq(path: Path) -> bool:
-    magic = path.open(mode="rb").read(4)
-    return magic in (b"IJBQ", b"IJSQ", b"JBSQ")
+    with path.open(mode="rb") as f:
+        magic = f.read(4)
+        return magic in (b"IJBQ", b"IJSQ", b"JBSQ")
