@@ -8,6 +8,7 @@ from typing import Dict, Iterator, List, Union
 
 from more_itertools import chunked, collapse, intersperse, mark_ends, windowed
 
+from jubeatools.info import __repository_url__, __version__
 from jubeatools.song import (
     BeatsTime,
     Chart,
@@ -17,7 +18,6 @@ from jubeatools.song import (
     TapNote,
     Timing,
 )
-from jubeatools.version import __version__
 
 from ..dump_tools import (
     DEFAULT_EXTRA_SYMBOLS,
@@ -248,7 +248,7 @@ def _dump_memo_chart(
     # Actual output to file
     file = StringIO()
     file.write(f"// Converted using jubeatools {__version__}\n")
-    file.write(f"// https://github.com/Stepland/jubeatools\n\n")
+    file.write(f"// {__repository_url__}\n\n")
     file.write(
         "\n\n".join(section.render(circle_free) for _, section in sections.items())
     )
