@@ -9,6 +9,7 @@ from typing import Dict, Iterator, List, Optional, Union
 from more_itertools import collapse, intersperse, mark_ends, windowed
 from sortedcontainers import SortedKeyList
 
+from jubeatools.info import __repository_url__, __version__
 from jubeatools.song import (
     BeatsTime,
     BPMEvent,
@@ -21,7 +22,6 @@ from jubeatools.song import (
     Timing,
 )
 from jubeatools.utils import lcm
-from jubeatools.version import __version__
 
 from ..command import dump_command
 from ..dump_tools import (
@@ -296,7 +296,7 @@ def _dump_memo2_chart(
     # Actual output to file
     file = StringIO()
     file.write(f"// Converted using jubeatools {__version__}\n")
-    file.write(f"// https://github.com/Stepland/jubeatools\n\n")
+    file.write(f"// {__repository_url__}\n\n")
 
     # Header
     if chart.level is not None:
